<?php

namespace SureCartBlocks\Blocks\Dashboard\CustomerCharges;

use SureCartBlocks\Blocks\Dashboard\DashboardPage;

/**
 * Checkout block
 */
class Block extends DashboardPage {
	/**
	 * Render the block
	 *
	 * @param array  $attributes Block attributes.
	 * @param string $content Post content.
	 *
	 * @return function
	 */
	public function render( $attributes, $content ) {
		// get the current page tab and possible id.
		$id   = sanitize_text_field( $_GET['charge']['id'] ?? null );
		$page = sanitize_text_field( $_GET['charge']['page'] ?? 1 );

		return $id ? $this->show( $id ) : $this->index( $page );
	}

	/**
	 * Show and individual checkout session.
	 *
	 * @param string $id Session ID.
	 *
	 * @return function
	 */
	public function show( $id ) {
		return \SureCart::blocks()->render(
			'web/dashboard/charges/show',
			[
				'id'            => $id,
				'customer_id'   => $this->customer_id,
				'order'         => [
					'query' => [
						'expand' => [],
					],
				],
				'subscriptions' => [
					'query' => [
						'order_ids'    => [ $id ],
						'customer_ids' => [ $this->customer_id ],
						'status'       => [ 'active', 'trialing' ],
						'page'         => 1,
						'per_page'     => 10,
					],
				],
				'charges'       => [
					'query' => [
						'order_ids'    => [ $id ],
						'customer_ids' => [ $this->customer_id ],
						'page'         => 1,
						'per_page'     => 10,
					],
				],
			]
		);
	}

	/**
	 * Show and individual checkout session.
	 *
	 * @param array $page Current page.
	 *
	 * @return function
	 */
	public function index( $page ) {
		if ( empty( $this->customer_id ) ) {
			return;
		}
		return \SureCart::blocks()->render(
			'web/dashboard/charges/index',
			[
				'query' => [
					'customer_ids' => [ $this->customer_id ],
					'page'         => 1,
					'per_page'     => 10,
				],
			]
		);
	}
}
